/****************************************************************
 *								*
 * Copyright (c) 2001-2021 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

/*** STUB FILE ***/

#include "mdef.h"
#include "io.h"
#include "op.h"

void op_zattach(mval *v)
{	error_def(ERR_UNIMPLOP);
	RTS_ERROR_ABT(VARLSTCNT(1) ERR_UNIMPLOP);
}
